@@ -7,7 +7,7 @@ from pyVC.Disks.Image import Disk as Image
 
 localhost = Machine()
 lan1 = VDE1([localhost], "lan1")
-root = Image([localhost], imagefile = "/sandbox/image.img")
+root = Image([localhost], path = "/sandbox/image.img")
 qemu1 = QEMU(localhost, "qemu1", networks = [lan1], disks = [root])
 
 lan1.start()
