@@ -42,6 +42,11 @@ for file in argv[1:]:
     configfile = None
 
   if configfile:
-    if not schema(configfile):
+    rc = None
+    try:
+      rc = schema(configfile)
+    except TypeError:
+      rc = schema.validate(configfile)
+    if not rc:
       print "ERROR: file %s does not validate with schema." % file
       print schema.error_log.__repr__()
